@@ -125,8 +125,6 @@ public class DescriptorReaderImpl implements DescriptorReader {
 
     private BlockingIteratorImpl<Descriptor> descriptorQueue;
 
-    private File autoSaveHistoryFile;
-
     private File manualSaveHistoryFile;
 
     private List<File> tarballs = new ArrayList<>();
@@ -146,7 +144,6 @@ public class DescriptorReaderImpl implements DescriptorReader {
         File manualSaveHistoryFile, SortedMap<String, Long> excludedFiles) {
       this.descriptorFiles = descriptorFiles;
       this.descriptorQueue = descriptorQueue;
-      this.autoSaveHistoryFile = autoSaveHistoryFile;
       this.manualSaveHistoryFile = manualSaveHistoryFile;
       if (excludedFiles != null) {
         this.excludedFilesBefore = excludedFiles;
@@ -156,29 +153,25 @@ public class DescriptorReaderImpl implements DescriptorReader {
 
     public void run() {
       try {
-        this.readOldHistory(this.autoSaveHistoryFile);
         this.readOldHistory(this.manualSaveHistoryFile);
         this.readDescriptorFiles();
         this.readTarballs();
         this.hasFinishedReading = true;
       } catch (Throwable t) {
-        log.error("Bug: uncaught exception or error while "
-            + "reading descriptors: " + t.getMessage(), t);
+        log.error("Bug: uncaught exception or error while reading descriptors.",
+            t);
       } finally {
         if (null != this.descriptorQueue) {
           this.descriptorQueue.setOutOfDescriptors();
         }
       }
-      if (this.hasFinishedReading) {
-        this.writeNewHistory(this.autoSaveHistoryFile);
-      }
     }
 
     private void readOldHistory(File historyFile) {
       if (historyFile == null || !historyFile.exists()) {
         return;
       }
-      List<String> lines = null;
+      List<String> lines;
       try {
         lines = Files.readAllLines(historyFile.toPath(),
             StandardCharsets.UTF_8);
@@ -194,7 +187,6 @@ public class DescriptorReaderImpl implements DescriptorReader {
         }
       } catch (IOException | NumberFormatException e) {
         log.warn("Trouble reading given history file {}.", historyFile, e);
-        return;
       }
     }
 
@@ -237,8 +229,7 @@ public class DescriptorReaderImpl implements DescriptorReader {
           try {
             String absolutePath = file.getAbsolutePath();
             long lastModifiedMillis = file.lastModified();
-            if (this.excludedFilesBefore.containsKey(absolutePath)
-                && this.excludedFilesBefore.get(absolutePath)
+            if (this.excludedFilesBefore.getOrDefault(absolutePath, 0L)
                 == lastModifiedMillis) {
               this.excludedFilesAfter.put(absolutePath, lastModifiedMillis);
               continue;
