@@ -1,4 +1,4 @@
-/* Copyright 2016--2017 The Tor Project
+/* Copyright 2016--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.descriptor.index;
@@ -131,7 +131,7 @@ public class DescriptorIndexCollectorTest {
     IndexNode in = new IndexNode("2016-01-01 01:01",
         remoteDirectory, null, dm);
     File indexFile = tmpf.newFile(name);
-    in.writeIndex(indexFile.toPath(), in);
+    IndexNode.writeIndex(indexFile.toPath(), in);
     return indexFile;
   }
 
@@ -276,7 +276,7 @@ public class DescriptorIndexCollectorTest {
   }
 
   @Test(expected = IllegalArgumentException.class)
-  public void testNullDirectory() throws IOException {
+  public void testNullDirectory() {
     new DescriptorIndexCollector().collectDescriptors(
         null, new String[]{}, 100L, null, false);
   }
@@ -288,7 +288,7 @@ public class DescriptorIndexCollectorTest {
     SortedMap<String, FileNode> fm = new TreeMap<>();
     fm.put("readonly", new FileNode("w", 2L, "2100-01-01 01:01"));
     new DescriptorIndexCollector()
-        .fetchRemoteFiles("", fm, 100L, dir, new TreeMap<String, Long>());
+        .fetchRemoteFiles("", fm, 100L, dir, new TreeMap<>());
   }
 }
 
